const puppeteer = require('puppeteer-extra');
const StealthPlugin = require('puppeteer-extra-plugin-stealth');
const AdBlockerPlugin = require('puppeteer-extra-plugin-adblocker');
const ArgsParser = require('./classes/utils/ArgsParser');
const KissAsianScraper = require('./classes/scraping/KissAsianScraper');
const JDownloaderClient = require('./classes/download/JDownloaderClient');
const credentials = require('../data/credentials.json');

const args = new ArgsParser().parse(process.argv.slice(2));

puppeteer.use(StealthPlugin());
puppeteer.use(AdBlockerPlugin({ blockTrackers: true }));

const main = async() => {
  const browser = await puppeteer.launch({ headless: !args.display, slowMo: 250 });
  const page = await browser.newPage();

  const scraper = new KissAsianScraper(page);
  const downloader = new JDownloaderClient(credentials.jdownloader);

  await downloader.load();
  await scraper.load();
  await scraper.authenticate(credentials.kissasian);

  const media = await scraper.getMediaData('https://kissasian.li/Drama/My-Roommate-is-a-Gumiho');
  
  await scraper.populateMediaDownloadURLs(media);
};

main();
